==> jc-1.4.0.tar.gz: gnu/regexp/REException.h <==
// public class gnu.regexp.REException

// class file dependencies
// @dep_class 3bc9b54388986409 gnu_regexp_REException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_regexp_REException_H_
#define _JC_gnu_regexp_REException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_regexp_REException$sub_refs	_jc_gnu_regexp_REException$sub_refs;
typedef struct _jc_gnu_regexp_REException$sub_nonrefs	_jc_gnu_regexp_REException$sub_nonrefs;
typedef struct _jc_gnu_regexp_REException$refs	_jc_gnu_regexp_REException$refs;
typedef struct _jc_gnu_regexp_REException$nonrefs	_jc_gnu_regexp_REException$nonrefs;
typedef struct _jc_gnu_regexp_REException$object	_jc_gnu_regexp_REException$object;

typedef struct _jc_gnu_regexp_REException$fields_struct	_jc_gnu_regexp_REException$fields_struct;
typedef const struct _jc_gnu_regexp_REException$vmethods	_jc_gnu_regexp_REException$vmethods;
typedef const struct _jc_gnu_regexp_REException$vtable	_jc_gnu_regexp_REException$vtable;
typedef const struct _jc_gnu_regexp_REException$vtype	_jc_gnu_regexp_REException$vtype;

// Class fields structure
struct _jc_gnu_regexp_REException$fields_struct {
	jint	REG__5fBADBR;
	jint	REG__5fBADPAT;
	jint	REG__5fBADRPT;
	jint	REG__5fEBRACE;
	jint	REG__5fEBRACK;
	jint	REG__5fECTYPE;
	jint	REG__5fEEND;
	jint	REG__5fEPAREN;
	jint	REG__5fERANGE;
	jint	REG__5fESCAPE;
	jint	REG__5fESIZE;
	jint	REG__5fESPACE;
	jint	REG__5fESUBREG;
};
extern _jc_gnu_regexp_REException$fields_struct _jc_gnu_regexp_REException$class_fields;

// Constructors
extern void _jc_gnu_regexp_REException$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_gnu_regexp_REException$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_regexp_REException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_gnu_regexp_REException$object *);
extern jint _jc_gnu_regexp_REException$method$getPosition$4d9f36ed091d8187(_jc_env *, struct _jc_gnu_regexp_REException$object *);
extern jint _jc_gnu_regexp_REException$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_gnu_regexp_REException$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_REException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_gnu_regexp_REException$method_info$getPosition$4d9f36ed091d8187;
extern _jc_method _jc_gnu_regexp_REException$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_gnu_regexp_REException$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_gnu_regexp_REException$object *);
	jint	(*getPosition$4d9f36ed091d8187)(_jc_env *, struct _jc_gnu_regexp_REException$object *);
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_gnu_regexp_REException$object *);
};

// Vtable
struct _jc_gnu_regexp_REException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_regexp_REException$vmethods	gnu_regexp_REException;
};

// Vtype
struct _jc_gnu_regexp_REException$vtype {
	_jc_type			type;
	_jc_gnu_regexp_REException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_REException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_REException$refs {
    _jc_gnu_regexp_REException$sub_refs	gnu_regexp_REException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_REException$sub_nonrefs {
	jint	type;
	jint	pos;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_REException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_regexp_REException$sub_nonrefs	gnu_regexp_REException;
};

// Object instance structure
struct _jc_gnu_regexp_REException$object {
	_jc_gnu_regexp_REException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_REException$vtype	*vtype;
	_jc_gnu_regexp_REException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_REException$vtype _jc_gnu_regexp_REException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_REException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_REException$class_object;

#endif	/* _JC_gnu_regexp_REException_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/REException.h <==
// public class gnu.regexp.REException

// class file dependencies
// @dep_class 3bc9b54388986409 gnu_regexp_REException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_regexp_REException_H_
#define _JC_gnu_regexp_REException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_regexp_REException$sub_refs	_jc_gnu_regexp_REException$sub_refs;
typedef struct _jc_gnu_regexp_REException$sub_nonrefs	_jc_gnu_regexp_REException$sub_nonrefs;
typedef struct _jc_gnu_regexp_REException$refs	_jc_gnu_regexp_REException$refs;
typedef struct _jc_gnu_regexp_REException$nonrefs	_jc_gnu_regexp_REException$nonrefs;
typedef struct _jc_gnu_regexp_REException$object	_jc_gnu_regexp_REException$object;

typedef struct _jc_gnu_regexp_REException$fields_struct	_jc_gnu_regexp_REException$fields_struct;
typedef const struct _jc_gnu_regexp_REException$vmethods	_jc_gnu_regexp_REException$vmethods;
typedef const struct _jc_gnu_regexp_REException$vtable	_jc_gnu_regexp_REException$vtable;
typedef const struct _jc_gnu_regexp_REException$vtype	_jc_gnu_regexp_REException$vtype;

// Class fields structure
struct _jc_gnu_regexp_REException$fields_struct {
	jint	REG__5fBADBR;
	jint	REG__5fBADPAT;
	jint	REG__5fBADRPT;
	jint	REG__5fEBRACE;
	jint	REG__5fEBRACK;
	jint	REG__5fECTYPE;
	jint	REG__5fEEND;
	jint	REG__5fEPAREN;
	jint	REG__5fERANGE;
	jint	REG__5fESCAPE;
	jint	REG__5fESIZE;
	jint	REG__5fESPACE;
	jint	REG__5fESUBREG;
};
extern _jc_gnu_regexp_REException$fields_struct _jc_gnu_regexp_REException$class_fields;

// Constructors
extern void _jc_gnu_regexp_REException$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_gnu_regexp_REException$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_regexp_REException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_gnu_regexp_REException$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_REException$method$getPosition$4d9f36ed091d8187(_jc_env *, struct _jc_gnu_regexp_REException$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_REException$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_gnu_regexp_REException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_REException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_gnu_regexp_REException$method_info$getPosition$4d9f36ed091d8187;
extern _jc_method _jc_gnu_regexp_REException$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_gnu_regexp_REException$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_gnu_regexp_REException$object *) _JC_JCNI_ATTR;
	jint	(*getPosition$4d9f36ed091d8187)(_jc_env *, struct _jc_gnu_regexp_REException$object *) _JC_JCNI_ATTR;
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_gnu_regexp_REException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_REException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_regexp_REException$vmethods	gnu_regexp_REException;
};

// Vtype
struct _jc_gnu_regexp_REException$vtype {
	_jc_type			type;
	_jc_gnu_regexp_REException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_REException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_REException$refs {
    _jc_gnu_regexp_REException$sub_refs	gnu_regexp_REException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_REException$sub_nonrefs {
	jint	type;
	jint	pos;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_REException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_regexp_REException$sub_nonrefs	gnu_regexp_REException;
};

// Object instance structure
struct _jc_gnu_regexp_REException$object {
	_jc_gnu_regexp_REException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_REException$vtype	*vtype;
	_jc_gnu_regexp_REException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_REException$vtype _jc_gnu_regexp_REException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_REException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_REException$class_object;

#endif	/* _JC_gnu_regexp_REException_H_ */
